package com.bsb.incubator.vaadin.addressbook.ui;

import com.bsb.incubator.vaadin.addressbook.AddressBookApplication;
import com.bsb.incubator.vaadin.addressbook.container.PersonContainer;
import com.bsb.incubator.vaadin.addressbook.domain.Person;
import com.vaadin.terminal.ExternalResource;
import com.vaadin.ui.Component;
import com.vaadin.ui.Link;
import com.vaadin.ui.Table;

/**
 * @author Stephane Nicoll
 */
public class PersonList extends Table {

    public PersonList(AddressBookApplication app) {

        // Enable advanced features
        setColumnCollapsingAllowed(true);
        setColumnReorderingAllowed(true);

        // customize email column to have mailto: links using column generator
        addGeneratedColumn("email", new ColumnGenerator() {
            public Component generateCell(Table source, Object itemId,
                                          Object columnId) {
                Person p = (Person) itemId;
                Link l = new Link();
                l.setResource(new ExternalResource("mailto:" + p.getEmail()));
                l.setCaption(p.getEmail());
                return l;
            }
        });

        setSizeFull();
        setContainerDataSource(app.getDataSource());
        setVisibleColumns(PersonContainer.NATURAL_COL_ORDER);
        setColumnHeaders(PersonContainer.COL_HEADERS_ENGLISH);

        //Make table selectable, react immediately to user events, and pass events to the
        //controller (our main application)
        setSelectable(true);
        setImmediate(true);
        addListener((ValueChangeListener) app);
        /* We don't want to allow users to de-select a row */
        setNullSelectionAllowed(false);
    }

}
