package com.bsb.incubator.vaadin.addressbook.ui;

import com.bsb.incubator.vaadin.addressbook.AddressBookApplication;
import com.bsb.incubator.vaadin.addressbook.container.PersonContainer;
import com.bsb.incubator.vaadin.addressbook.ui.internal.SearchFilter;
import com.vaadin.ui.Button;
import com.vaadin.ui.CheckBox;
import com.vaadin.ui.FormLayout;
import com.vaadin.ui.NativeSelect;
import com.vaadin.ui.Panel;
import com.vaadin.ui.TextField;

/**
 * @author Stephane Nicoll
 */
public class SearchView extends Panel {

    private final TextField tf;
    private final NativeSelect fieldToSearch;
    private final CheckBox saveSearch;
    private final TextField searchName;
    private final AddressBookApplication app;

    public SearchView(final AddressBookApplication app) {
        this.app = app;

        setCaption("Search contacts");
        setSizeFull();
        addStyleName("view");

        /* Use a FormLayout as main layout for this Panel */
        FormLayout formLayout = new FormLayout();
        setContent(formLayout);
        /* Create UI components */
        tf = new TextField("Search term");
        fieldToSearch = new NativeSelect("Field to search");
        saveSearch = new CheckBox("Save search");
        searchName = new TextField("Search name");
        Button search = new Button("Search");
        /* Initialize fieldToSearch */
        for (int i = 0; i < PersonContainer.NATURAL_COL_ORDER.length; i++) {
            fieldToSearch.addItem(PersonContainer.NATURAL_COL_ORDER[i]);
            fieldToSearch.setItemCaption(PersonContainer.NATURAL_COL_ORDER[i],
                    PersonContainer.COL_HEADERS_ENGLISH[i]);
        }
        fieldToSearch.setValue(PersonContainer.DEFAULT_SEARCH_FIELD);
        fieldToSearch.setNullSelectionAllowed(false);
        /* Initialize save checkbox */
        saveSearch.setValue(true);
        /* Add all the created components to the form */
        addComponent(tf);
        addComponent(fieldToSearch);
        addComponent(saveSearch);
        addComponent(searchName);
        addComponent(search);

        saveSearch.setImmediate(true);
        saveSearch.addListener(new Button.ClickListener() {
            public void buttonClick(Button.ClickEvent event) {
                searchName.setVisible(event.getButton().booleanValue());
            }
        });
        search.addListener(new Button.ClickListener() {
            public void buttonClick(Button.ClickEvent event) {
                performSearch();
            }
        });
    }

    private void performSearch() {
        String searchTerm = (String) tf.getValue();
        SearchFilter searchFilter = new SearchFilter(fieldToSearch.getValue(),
                searchTerm, (String) searchName.getValue());
        if (saveSearch.booleanValue()) {
            app.saveSearch(searchFilter);
        }
        app.search(searchFilter);


    }
}

